<?php

namespace Drupal\Tests\node\Kernel\Migrate;

use Drupal\KernelTests\KernelTestBase;
use Drupal\migrate\Exception\RequirementsException;
use Drupal\migrate\Plugin\migrate\source\SqlBase;
use Drupal\migrate\Plugin\RequirementsInterface;

/**
 * Tests the migration plugin manager with node derivers.
 *
 * @coversDefaultClass \Drupal\migrate\Plugin\MigratePluginManager
 * @group node
 */
class MigratePluginListTest extends KernelTestBase {

  /**
   * {@inheritdoc}
   */
  public static $modules = [
    // Include modules defining required migrations for the node migrations.
    'migrate',
    'migrate_drupal',
    'field',
    'filter',
    'node',
    'user',
  ];

  /**
   * @covers ::getDefinitions
   */
  public function testGetDefinitions() {
    // Make sure retrieving these migration plugins in the absence of a database
    // connection does not throw any errors.
    $migration_plugins = $this->container->get('plugin.manager.migration')->createInstances([]);
    // Any database-based source plugins should fail a requirements test in the
    // absence of a database connection.
    /** @var \Drupal\migrate\Plugin\Migration $migration */
    foreach ($migration_plugins as $id => $migration) {
      if ($migration->getSourcePlugin() instanceof RequirementsInterface) {
        try {
          $migration->getSourcePlugin()->checkRequirements();
        }
        catch (RequirementsException $e) {
          unset($migration_plugins[$id]);
        }
      }
    }

    // Without a connection defined, no database-based plugins should be
    // returned.
    foreach ($migration_plugins as $id => $migration) {
      $this->assertNotInstanceOf(SqlBase::class, $migration->getSourcePlugin());
    }
  }

}
